==> migrate_wizard-2.0.7-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWGenericText.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'generic_text' field type.
 *
 * @FieldType(
 *   id = "generic_text",
 * )
 */
class FieldTypeMWGenericText extends FieldTypeMWBase {

    public static function getD7MigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $langcode = NULL): void {

    $method = 'process';
    if (($data_field['destiny'] == 'title' && $wildcard_yml_config["destination"]["plugin"] == 'entity:node') ||
        ($data_field['destiny'] == 'name' && $wildcard_yml_config["destination"]["plugin"] == 'entity:taxonomy_term')){
      $method = 'row';
    }

    $sourceName = $origin_field;

    if($data_field['destiny'] == 'name' && $wildcard_yml_config["source"]["origin_type"] == 'vocabulary' && $langcode != NULL){
      $sourceName = 'name_translated';
    }

    $array_config[$data_field['destiny']][] = [
      'plugin' => 'skip_on_empty',
      'source' => $sourceName,
      'method' => $method,
    ];

    if($sourceName != 'title' && $sourceName != 'name' && $sourceName != 'name_translated'){
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'sub_process',
        'process' => [
          'value' => 'value',
          'format' => 'format'
        ]
      ];
    }

    $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);

  }
}

==> migrate_wizard-2.0.10-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWGenericText.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'generic_text' field type.
 *
 * @FieldType(
 *     id="generic_text",
 * )
 */
class FieldTypeMWGenericText extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $langcode = NULL): void {
    $method = 'process';

    if (($data_field['destiny'] === 'title' && $wildcard_yml_config['destination']['plugin'] === 'entity:node')
        || ($data_field['destiny'] === 'name' && $wildcard_yml_config['destination']['plugin'] === 'entity:taxonomy_term')) {
      $method = 'row';
    }

    $sourceName = $origin_field;

    if ($data_field['destiny'] === 'name' && $wildcard_yml_config['source']['origin_type'] === 'vocabulary' && $langcode !== NULL) {
      $sourceName = 'name_translated';
    }

    $array_config[$data_field['destiny']][] = [
      'plugin' => 'skip_on_empty',
      'source' => $sourceName,
      'method' => $method,
    ];

    if ($sourceName !== 'title' && $sourceName !== 'name' && $sourceName !== 'name_translated') {
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'sub_process',
        'process' => [
          'value' => 'value',
          'format' => 'format',
        ],
      ];
    }

    $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);
  }

}
